@@ -79,19 +79,9 @@ void Graph2DMobile::resetViewport()
 
 void Graph2DMobile::modelChanged()
 {
-    connect(model(), &QAbstractItemModel::dataChanged,
-        this, &Graph2DMobile::updateFuncs);
-    connect(model(), &QAbstractItemModel::rowsInserted,
-        this, &Graph2DMobile::addFuncs);
-    connect(model(), &QAbstractItemModel::rowsRemoved,
-        this, &Graph2DMobile::removeFuncs);
+    Q_EMIT modelHasChanged();
 }
 
-void Graph2DMobile::addFuncs(const QModelIndex& parent, int start, int end) { updateFunctions(parent, start, end); }
-
-void Graph2DMobile::removeFuncs(const QModelIndex&, int, int) { forceRepaint(); }
-void Graph2DMobile::updateFuncs(const QModelIndex& start, const QModelIndex& end) { updateFunctions(QModelIndex(), start.row(), end.row()); }
-
 void Graph2DMobile::scale(qreal s, int x, int y)
 {
     QRectF userViewport = lastUserViewport();
@@ -117,7 +107,7 @@ QStringList Graph2DMobile::addFunction(const QString& expression, const QSharedP
 
 void Graph2DMobile::setTicksShownAtAll(bool shown)
 {
-    Qt::Orientations show = shown ? Qt::Vertical|Qt::Horizontal : Qt::Orientations(nullptr);
+    Qt::Orientations show = shown ? Qt::Vertical|Qt::Horizontal : Qt::Orientations(0);
     setShowTicks(show);
     setShowTickLabels(show);
 }
